@@ -15,16 +15,19 @@ if TYPE_CHECKING:
 
 
 def render(options: Options, tree: PackageDAG) -> None:
-    if options.json:
-        print(render_json(tree))  # noqa: T201
-    elif options.json_tree:
-        print(render_json_tree(tree))  # noqa: T201
-    elif options.mermaid:
-        print(render_mermaid(tree))  # noqa: T201
-    elif options.output_format:
-        render_graphviz(tree, output_format=options.output_format, reverse=options.reverse)
-    elif options.freeze:
+    output_format = options.output_format
+    if output_format == "json":
+        render_json(tree)
+    elif output_format == "json-tree":
+        render_json_tree(tree)
+    elif output_format == "mermaid":
+        render_mermaid(tree)
+    elif output_format == "freeze":
         render_freeze(tree, max_depth=options.depth, list_all=options.all)
+    elif output_format.startswith("graphviz-"):
+        render_graphviz(
+            tree, output_format=output_format[len("graphviz-") :], reverse=options.reverse, max_depth=options.depth
+        )
     else:
         render_text(
             tree,
